@@ -54,7 +54,8 @@ class OKULARCORE_EXPORT Action
             Sound,      ///< Play a sound
             Movie,      ///< Play a movie
             Script,     ///< Executes a Script code
-            Rendition   ///< Play a movie and/or execute a Script code @since 0.16 (KDE 4.10)
+            Rendition,  ///< Play a movie and/or execute a Script code @since 0.16 (KDE 4.10)
+            BackendOpaque ///< Calls back to the backend with the action @since 1.1
         };
 
         /**
@@ -96,6 +97,21 @@ class OKULARCORE_EXPORT Action
          */
         QVariant nativeId() const;
 
+        /**
+         * Returns the next actions to be executed after.
+         *
+         * @since 1.5
+         */
+        QVector< Action * > nextActions() const;
+
+        /**
+         * Sets the next actions.
+         *
+         * Takes ownership of the objects in the actions vector.
+         * @since 1.5
+         */
+        void setNextActions( const QVector< Action * > &actions );
+
     protected:
         /// @cond PRIVATE
         Action( ActionPrivate &dd );
@@ -141,12 +157,12 @@ class OKULARCORE_EXPORT GotoAction : public Action
         /**
          * Returns the action type.
          */
-        ActionType actionType() const;
+        ActionType actionType() const override;
 
         /**
          * Returns the action tip.
          */
-        QString actionTip() const;
+        QString actionTip() const override;
 
         /**
          * Returns whether the goto action points to an external document.
@@ -197,12 +213,12 @@ class OKULARCORE_EXPORT ExecuteAction : public Action
         /**
          * Returns the action type.
          */
-        ActionType actionType() const;
+        ActionType actionType() const override;
 
         /**
          * Returns the action tip.
          */
-        QString actionTip() const;
+        QString actionTip() const override;
 
         /**
          * Returns the file name of the application to execute.
@@ -241,12 +257,12 @@ class OKULARCORE_EXPORT BrowseAction : public Action
         /**
          * Returns the action type.
          */
-        ActionType actionType() const;
+        ActionType actionType() const override;
 
         /**
          * Returns the action tip.
          */
-        QString actionTip() const;
+        QString actionTip() const override;
 
         /**
          * Returns the url to browse.
@@ -300,12 +316,12 @@ class OKULARCORE_EXPORT DocumentAction : public Action
         /**
          * Returns the action type.
          */
-        ActionType actionType() const;
+        ActionType actionType() const override;
 
         /**
          * Returns the action tip.
          */
-        QString actionTip() const;
+        QString actionTip() const override;
 
         /**
          * Returns the type of action.
@@ -342,12 +358,12 @@ class OKULARCORE_EXPORT SoundAction : public Action
         /**
          * Returns the action type.
          */
-        ActionType actionType() const;
+        ActionType actionType() const override;
 
         /**
          * Returns the action tip.
          */
-        QString actionTip() const;
+        QString actionTip() const override;
 
         /**
          * Returns the volume of the sound.
@@ -402,12 +418,12 @@ class OKULARCORE_EXPORT ScriptAction : public Action
         /**
          * Returns the action type.
          */
-        ActionType actionType() const;
+        ActionType actionType() const override;
 
         /**
          * Returns the action tip.
          */
-        QString actionTip() const;
+        QString actionTip() const override;
 
         /**
          * Returns the type of action.
@@ -455,12 +471,12 @@ class OKULARCORE_EXPORT MovieAction : public Action
         /**
          * Returns the action type.
          */
-        ActionType actionType() const;
+        ActionType actionType() const override;
 
         /**
          * Returns the action tip.
          */
-        QString actionTip() const;
+        QString actionTip() const override;
 
         /**
          * Returns the operation type.
@@ -520,12 +536,12 @@ class OKULARCORE_EXPORT RenditionAction : public Action
         /**
          * Returns the action type.
          */
-        ActionType actionType() const;
+        ActionType actionType() const override;
 
         /**
          * Returns the action tip.
          */
-        QString actionTip() const;
+        QString actionTip() const override;
 
         /**
          * Returns the operation type.
@@ -562,6 +578,20 @@ class OKULARCORE_EXPORT RenditionAction : public Action
         Q_DISABLE_COPY( RenditionAction )
 };
 
+class OKULARCORE_EXPORT BackendOpaqueAction : public Action
+{
+    public:
+        BackendOpaqueAction();
+
+        /**
+         * Returns the action type.
+         */
+        ActionType actionType() const override;
+
+    private:
+        Q_DISABLE_COPY( BackendOpaqueAction )
+};
+
 }
 
 #endif
